@@ -1,7 +1,7 @@
 package App::podsel;
 
-our $DATE = '2019-12-14'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2019-12-15'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -49,13 +49,14 @@ $SPEC{podsel} = {
                     of=>['str*', in=>['Pod5','Nester']],
                     #'x.perl.coerce_rules' => ['From_str::comma_sep'],
                 }],
+            cmdline_aliases => {t=>{}},
             description => <<'_',
 
 By default, the "stock" Pod::Elemental parser will be generic and not very
 helpful in parsing your typical POD (Perl 5 variant) documents. You usually want
 to add:
 
-    --transform Pod5 --transform Nester
+    -t Pod5 -t Nester
 
 The following are available transforms:
 
@@ -180,6 +181,7 @@ sub podsel {
         csel_opts => {
             class_prefixes=>[
                 'Pod::Elemental::Element::Generic',
+                'Pod::Elemental::Element::Pod5',
                 'Pod::Elemental::Element',
                 'Pod::Elemental',
             ]},
@@ -213,7 +215,7 @@ App::podsel - Select Pod::Elemental nodes using CSel syntax
 
 =head1 VERSION
 
-This document describes version 0.005 of App::podsel (from Perl distribution App-podsel), released on 2019-12-14.
+This document describes version 0.006 of App::podsel (from Perl distribution App-podsel), released on 2019-12-15.
 
 =head1 SYNOPSIS
 
@@ -300,7 +302,7 @@ By default, the "stock" Pod::Elemental parser will be generic and not very
 helpful in parsing your typical POD (Perl 5 variant) documents. You usually want
 to add:
 
- --transform Pod5 --transform Nester
+ -t Pod5 -t Nester
 
 The following are available transforms:
 
